Token

Struct Token 

pub struct Token<N> {
    pub name: N,
    pub str: String,
    pub pos: TextPosition,
}
A specific occurence of a token in the text that was tokenized.

Contains the name of the token type, str, a String that contains the text the token matched, and pos, the TextPosition of the token in the text.

Fields

name: Nstr: Stringpos: TextPosition

Implementations

Source

impl<N> Token<N>

pub fn new(name: N, str: String, pos: TextPosition) -> Self

Creates a new token.

Examples
use sprout::tokenize::Token;
 
enum TokenName { ABC }
 
Token::new(TokenName::ABC, "abc".to_string(), TextPosition::new(4, 20, 69));