pub struct Token<N> {
pub name: N,
pub str: String,
pub pos: TextPosition,
}Expand description
A specific occurence of a token in the text that was tokenized.
Contains the name of the token type, str, a String that contains the
text the token matched, and pos, the TextPosition of the token in the text.
Fields
name: Nstr: Stringpos: TextPositionImplementations